@@ -3,7 +3,7 @@ use 5.00503;
 use strict;
 
 use vars qw(@ISA @EXPORT $VERSION $MUST_REBOOT %Config);
-$VERSION = '1.43';
+$VERSION = '1.45';
 $VERSION = eval $VERSION;
 
 use AutoSplit;
@@ -436,7 +436,9 @@ sub _can_write_dir {
     my $path='';
     my @make;
     while (@dirs) {
-        $dir = File::Spec->catdir($vol,@dirs);
+        $dir = File::Spec->catdir(@dirs);
+        $dir = File::Spec->catpath($vol,$dir,'') 
+                if defined $vol and length $vol;
         next if ( $dir eq $path );
         if ( ! -e $dir ) {
             unshift @make,$dir;
@@ -674,7 +676,7 @@ sub install { #XXX OS-SPECIFIC
             print "Skipping $targetfile (unchanged)\n" if $verbose;
         }
 
-        if ( defined $inc_uninstall ) {
+        if ( $inc_uninstall ) {
             inc_uninstall($sourcefile,$ffd, $verbose,
                           $nonono,
                           $realtarget ne $targetfile ? $realtarget : "");
